==> office-ui-fabric-vue-7.0.26.tgz: package/lib/components/Overlay/Overlay.base.js <==
import '../node_modules/core-js/modules/es.date.to-string.js';
import '../node_modules/core-js/modules/es.object.to-string.js';
import '../node_modules/core-js/modules/es.reflect.construct.js';
import '../node_modules/core-js/modules/es.regexp.to-string.js';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction();

var OverlayBase = function (_BaseComponent) {
  _inherits(OverlayBase, _BaseComponent);

  var _super = _createSuper(OverlayBase);

  function OverlayBase() {
    _classCallCheck(this, OverlayBase);

    return _super.apply(this, arguments);
  }

  _createClass(OverlayBase, [{
    key: "render",
    value: function render() {
      var h = arguments[0];
      var classNames = this.classNames;
      return h("div", {
        "class": classNames.root
      }, [this.$slots["default"]]);
    }
  }, {
    key: "classNames",
    get: function get() {
      var theme = this.theme,
          className = this.className,
          isDark = this.dark;
      return getClassNames(this.styles, {
        theme: theme,
        className: className,
        isDark: isDark
      });
    }
  }]);

  return OverlayBase;
}(BaseComponent);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], OverlayBase.prototype, "dark", void 0);

OverlayBase = __decorate([Component], OverlayBase);

export { OverlayBase };

==> office-ui-fabric-vue-7.0.27.tgz: package/lib/components/Overlay/Overlay.base.js <==
import 'core-js/modules/es.object.to-string';
import 'core-js/modules/es.reflect.construct';
import 'core-js/modules/es.regexp.to-string';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction();

var OverlayBase = function (_BaseComponent) {
  _inherits(OverlayBase, _BaseComponent);

  var _super = _createSuper(OverlayBase);

  function OverlayBase() {
    _classCallCheck(this, OverlayBase);

    return _super.apply(this, arguments);
  }

  _createClass(OverlayBase, [{
    key: "render",
    value: function render() {
      var h = arguments[0];
      var classNames = this.classNames;
      return h("div", {
        "class": classNames.root
      }, [this.$slots.default]);
    }
  }, {
    key: "classNames",
    get: function get() {
      var theme = this.theme,
          className = this.className,
          isDark = this.dark;
      return getClassNames(this.styles, {
        theme: theme,
        className: className,
        isDark: isDark
      });
    }
  }]);

  return OverlayBase;
}(BaseComponent);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], OverlayBase.prototype, "dark", void 0);

OverlayBase = __decorate([Component], OverlayBase);

export { OverlayBase };
